==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-feature-card.dart <==
/*
Widget Name:
- Custom Feature Card

Description:
- Cards contain content and actions about a single subject.
- Feature Card contains both image and an Icon in top.
- Either Image or Icon can be visible based on the input as the user wants.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-feature-card.dart';

Usage:
- Defining the callback and Feature Card objects

  final MaterialCardData FeatureCardata = new MaterialCardData(
      btnGrpList1: [
        SizedBox(
          width: 150.0,
          height: 35.0,
          child: FlatButton(
            disabledColor: Colors.red,
            child: Text(
              'qwe',
              style: TextStyle(fontSize: 16.0),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
            ),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: BorderSide(color: Colors.red)),
            onPressed: null,
          ),
        ),
        SizedBox(
          width: 150.0,
          height: 35.0,
          child: FlatButton(
            disabledColor: Colors.red,
            child: Text(
              'Click',
              style: TextStyle(fontSize: 16.0),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
            ),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: BorderSide(color: Colors.red)),
            onPressed: null,
          ),
        ),
      ],
      btnGrpList2: [
        RaisedButton(
          padding: EdgeInsets.only(left: 40.0, right: 40.0),
          color: Colors.red,
          child: Text(
            'Click',
            style: TextStyle(
                fontSize: 16.0,
                color: Colors.white),
          ),
          onPressed: null,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(20.0),
          ),
        ),
      ],
      iconVisibility: false,
      imgDecoration: BoxDecoration(
        border: Border.all(color: Colors.green, width: 5),
        color: Colors.red,
        shape: BoxShape.circle,
      ),
      textStyle2: TextStyle(
        color: Colors.red,
        fontSize: 20.0,
      ),
      title: 'Title Goes Here',
      imgType: 'asset',
      containerWidth: 380,
      imgPath: 'images/card1.png',
      btnText: 'Done',
      containerHeight: 620,
      bodyText:
          "Lorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum si");

****Note:
- Here iconVisibility decides .
- imgType decides weather the image source is network image or asset image.
- btnGrpList1 & btnGrpList2 are two individual list of widget, that will appear in the bottom part of feature card.

Widget call:
              customFeatureCard(FeatureCardata),
Author:
- Satyabrat Padhy
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

Widget customFeatureCard(MaterialCardData data) {
  bool iconVisibility;
  ImageProvider image;

  if (data.iconVisibility != null && data.iconVisibility) {
    iconVisibility = data.iconVisibility;
  } else {
    iconVisibility = false;
  }

  if (data.imgType != null && data.imgType == constants.Asset ||
      data.imgType == constants.asset) {
    image = (data.imgPath == null)
        ? AssetImage(constants.cardImagePath)
        : AssetImage(data.imgPath);
  } else if (data.imgType != null && data.imgType == constants.Network ||
      data.imgType == constants.network) {
    image = (data.imgPath == null)
        ? NetworkImage(constants.networkCardImagePath)
        : NetworkImage(data.imgPath);
  } else {
    image = NetworkImage(constants.networkCardImagePath);
  }

  return Container(
    height: data.containerHeight != null
        ? data.containerHeight
        : constants.heightFourHundred,
    width: data.containerWidth != null
        ? data.containerWidth
        : constants.heightThreeHundred,
    decoration: data.containerDecoration != null
        ? data.containerDecoration
        : BoxDecoration(
            color: MediumGreyThemeData().primaryColor,
            border: Border.all(
              color: MediumGreyThemeData().primaryColorDark,
              width: constants.heightOne,
            ),
            borderRadius: BorderRadius.circular(
                constants.heightFive * constants.heightThree),
          ),
    child: Padding(
      padding: EdgeInsets.all(
          data.padding1 != null ? data.padding1 : constants.heightTwenty),
      child: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            SizedBox(
              height: constants.heightThirty,
            ),
            Visibility(
              visible: iconVisibility ? false : true,
              child: Material(
                  type: MaterialType.transparency,
                  child: Ink(
                    decoration:
                        (data.imgDecoration != null && data.imgDecoration != '')
                            ? data.imgDecoration
                            : BoxDecoration(
                                border: Border.all(
                                    color: MediumGreyThemeData().highlightColor,
                                    width: constants.heightTwentyFive),
                                color: MediumGreyThemeData().hintColor,
                                shape: BoxShape.circle,
                              ),
                    child: InkWell(
                      borderRadius: BorderRadius.circular(
                          constants.heightHundred * constants.heightTen),
                      child: Semantics(
                        label: data.title != null
                            ? data.title
                            : constants.dialogHeader,
                        child: Padding(
                          padding: EdgeInsets.all(data.padding2 != null
                              ? data.padding2
                              : constants.heightTwenty),
                          child: CircleAvatar(
                            radius:
                                constants.heightThirty + constants.heightFive,
                            backgroundImage: (image != null)
                                ? image
                                : NetworkImage(constants.networkCardImagePath),
                          ),
                        ),
                      ),
                    ),
                  )),
            ),
            Visibility(
              visible: iconVisibility != null && iconVisibility == false
                  ? iconVisibility
                  : true,
              child: Material(
                  type: MaterialType.transparency,
                  child: Ink(
                    decoration: data.iconbgDecoration != null
                        ? data.iconbgDecoration
                        : BoxDecoration(
                            border: Border.all(
                                color:
                                    MediumGreyThemeData().unselectedWidgetColor,
                                width: constants.heightTwentyFive),
                            color: MediumGreyThemeData().highlightColor,
                            shape: BoxShape.circle,
                          ),
                    child: InkWell(
                      borderRadius: BorderRadius.circular(
                          constants.heightHundred * constants.heightTen),
                      child: Padding(
                        padding: EdgeInsets.all(data.padding3 != null
                            ? data.padding3
                            : constants.heightTwenty),
                        child: data.icon != null
                            ? data.icon
                            : Icon(
                                Icons.message,
                                size: constants.heightFourrty,
                                color: MediumGreyThemeData().primaryColor,
                              ),
                      ),
                    ),
                  )),
            ),
            SizedBox(
              height: constants.heightThirty,
            ),
            Text(
              data.title != null ? data.title : constants.dialogHeader,
              style: data.textStyle1 != null
                  ? data.textStyle1
                  : TextStyle(
                      color: MediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightThirty,
                    ),
              textAlign: TextAlign.justify,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            Text(
              data.bodyText != null ? data.bodyText : constants.dialogHeader,
              style: data.textStyle2 != null
                  ? data.textStyle2
                  : TextStyle(
                      color: MediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightTwenty,
                    ),
              textAlign: TextAlign.center,
              softWrap: true,
              maxLines: constants.intTwo * constants.intTwo,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightFourrty,
            ),
            Text(
              data.footerText != null
                  ? data.footerText
                  : constants.dialogHeader,
              style: data.textStyle3 != null
                  ? data.textStyle3
                  : TextStyle(
                      color: MediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightTwenty,
                    ),
              textAlign: TextAlign.justify,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.spaceBetween,
              children: data.btnGrpList1 != null ? data.btnGrpList1 : [],
            ),
            Divider(
              thickness: constants.heightThree,
              color: data.dividerColor != null
                  ? data.dividerColor
                  : MediumGreyThemeData().iconTheme.color,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.center,
              children: data.btnGrpList2 != null ? data.btnGrpList2 : [],
            ),
          ],
        ),
      ),
    ),
  );
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-feature-card.dart <==
/*
Widget Name:
- Custom Feature Card

Description:
- Cards contain content and actions about a single subject.
- Feature Card contains both image and an Icon in top.
- Either Image or Icon can be visible based on the input as the user wants.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-feature-card.dart';

Usage:
- Defining the callback and Feature Card objects

  final MaterialCardData FeatureCardata = new MaterialCardData(
      btnGrpList1: [
        SizedBox(
          width: 150.0,
          height: 35.0,
          child: FlatButton(
            disabledColor: Colors.red,
            child: Text(
              'qwe',
              style: TextStyle(fontSize: 16.0),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
            ),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: BorderSide(color: Colors.red)),
            onPressed: null,
          ),
        ),
        SizedBox(
          width: 150.0,
          height: 35.0,
          child: FlatButton(
            disabledColor: Colors.red,
            child: Text(
              'Click',
              style: TextStyle(fontSize: 16.0),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
            ),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(20.0),
                side: BorderSide(color: Colors.red)),
            onPressed: null,
          ),
        ),
      ],
      btnGrpList2: [
        RaisedButton(
          padding: EdgeInsets.only(left: 40.0, right: 40.0),
          color: Colors.red,
          child: Text(
            'Click',
            style: TextStyle(
                fontSize: 16.0,
                color: Colors.white),
          ),
          onPressed: null,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(20.0),
          ),
        ),
      ],
      iconVisibility: false,
      imgDecoration: BoxDecoration(
        border: Border.all(color: Colors.green, width: 5),
        color: Colors.red,
        shape: BoxShape.circle,
      ),
      textStyle2: TextStyle(
        color: Colors.red,
        fontSize: 20.0,
      ),
      title: 'Title Goes Here',
      imgType: 'asset',
      containerWidth: 380,
      imgPath: 'images/card1.png',
      btnText: 'Done',
      containerHeight: 620,
      bodyText:
          "Lorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum siLorem Ipsum si");

****Note:
- Here iconVisibility decides .
- imgType decides weather the image source is network image or asset image.
- btnGrpList1 & btnGrpList2 are two individual list of widget, that will appear in the bottom part of feature card.

Widget call:
              customFeatureCard(FeatureCardata),
Author:
- Satyabrat Padhy
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

Widget customFeatureCard(MaterialCardData data) {
  bool iconVisibility;
  ImageProvider image;

  if (data.iconVisibility != null && data.iconVisibility) {
    iconVisibility = data.iconVisibility;
  } else {
    iconVisibility = false;
  }

  if (data.imgType != null && data.imgType == constants.Asset ||
      data.imgType == constants.asset) {
    image = (data.imgPath == null)
        ? AssetImage(constants.cardImagePath)
        : AssetImage(data.imgPath);
  } else if (data.imgType != null && data.imgType == constants.Network ||
      data.imgType == constants.network) {
    image = (data.imgPath == null)
        ? NetworkImage(constants.networkCardImagePath)
        : NetworkImage(data.imgPath);
  } else {
    image = NetworkImage(constants.networkCardImagePath);
  }

  return Container(
    height: data.containerHeight != null
        ? data.containerHeight
        : constants.heightFourHundred,
    width: data.containerWidth != null
        ? data.containerWidth
        : constants.heightThreeHundred,
    decoration: data.containerDecoration != null
        ? data.containerDecoration
        : BoxDecoration(
            color: mediumGreyThemeData().primaryColor,
            border: Border.all(
              color: mediumGreyThemeData().primaryColorDark,
              width: constants.heightOne,
            ),
            borderRadius: BorderRadius.circular(
                constants.heightFive * constants.heightThree),
          ),
    child: Padding(
      padding: EdgeInsets.all(
          data.padding1 != null ? data.padding1 : constants.heightTwenty),
      child: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            SizedBox(
              height: constants.heightThirty,
            ),
            Visibility(
              visible: iconVisibility ? false : true,
              child: Material(
                  type: MaterialType.transparency,
                  child: Ink(
                    decoration:
                        (data.imgDecoration != null && data.imgDecoration.toString() != '')
                            ? data.imgDecoration
                            : BoxDecoration(
                                border: Border.all(
                                    color: mediumGreyThemeData().highlightColor,
                                    width: constants.heightTwentyFive),
                                color: mediumGreyThemeData().hintColor,
                                shape: BoxShape.circle,
                              ),
                    child: InkWell(
                      borderRadius: BorderRadius.circular(
                          constants.heightHundred * constants.heightTen),
                      child: Semantics(
                        label: data.title != null
                            ? data.title
                            : constants.dialogHeader,
                        child: Padding(
                          padding: EdgeInsets.all(data.padding2 != null
                              ? data.padding2
                              : constants.heightTwenty),
                          child: CircleAvatar(
                            radius:
                                constants.heightThirty + constants.heightFive,
                            backgroundImage: (image != null)
                                ? image
                                : NetworkImage(constants.networkCardImagePath),
                          ),
                        ),
                      ),
                    ),
                  )),
            ),
            Visibility(
              visible: iconVisibility != null && iconVisibility == false
                  ? iconVisibility
                  : true,
              child: Material(
                  type: MaterialType.transparency,
                  child: Ink(
                    decoration: data.iconbgDecoration != null
                        ? data.iconbgDecoration
                        : BoxDecoration(
                            border: Border.all(
                                color:
                                    mediumGreyThemeData().unselectedWidgetColor,
                                width: constants.heightTwentyFive),
                            color: mediumGreyThemeData().highlightColor,
                            shape: BoxShape.circle,
                          ),
                    child: InkWell(
                      borderRadius: BorderRadius.circular(
                          constants.heightHundred * constants.heightTen),
                      child: Padding(
                        padding: EdgeInsets.all(data.padding3 != null
                            ? data.padding3
                            : constants.heightTwenty),
                        child: data.icon != null
                            ? data.icon
                            : Icon(
                                Icons.message,
                                size: constants.heightFourrty,
                                color: mediumGreyThemeData().primaryColor,
                              ),
                      ),
                    ),
                  )),
            ),
            SizedBox(
              height: constants.heightThirty,
            ),
            Text(
              data.title != null ? data.title : constants.dialogHeader,
              style: data.textStyle1 != null
                  ? data.textStyle1
                  : TextStyle(
                      color: mediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightThirty,
                    ),
              textAlign: TextAlign.justify,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            Text(
              data.bodyText != null ? data.bodyText : constants.dialogHeader,
              style: data.textStyle2 != null
                  ? data.textStyle2
                  : TextStyle(
                      color: mediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightTwenty,
                    ),
              textAlign: TextAlign.center,
              softWrap: true,
              maxLines: constants.intTwo * constants.intTwo,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightFourrty,
            ),
            Text(
              data.footerText != null
                  ? data.footerText
                  : constants.dialogHeader,
              style: data.textStyle3 != null
                  ? data.textStyle3
                  : TextStyle(
                      color: mediumGreyThemeData().primaryColorDark,
                      fontSize: constants.heightTwenty,
                    ),
              textAlign: TextAlign.justify,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.spaceBetween,
              children: data.btnGrpList1 != null ? data.btnGrpList1 : [],
            ),
            Divider(
              thickness: constants.heightThree,
              color: data.dividerColor != null
                  ? data.dividerColor
                  : mediumGreyThemeData().iconTheme.color,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.center,
              children: data.btnGrpList2 != null ? data.btnGrpList2 : [],
            ),
          ],
        ),
      ),
    ),
  );
}
